#ifndef MEMORYGAMEBOARD_H
#define MEMORYGAMEBOARD_H

#include <QtDeclarative>
#include "memorycard.h"

class MemoryGameBoard : public QDeclarativeItem
{
    Q_OBJECT
    Q_PROPERTY(unsigned rows READ rows WRITE setRows NOTIFY rowsChanged)
    Q_PROPERTY(unsigned columns READ columns WRITE setColumns NOTIFY columnsChanged)
    Q_PROPERTY(unsigned elapsedSteps READ elapsedSteps NOTIFY elapsedStepsChanged)
    Q_PROPERTY(bool isGameStarted READ isGameStarted NOTIFY isGameStartedChanged)

    unsigned _rows, _columns, _margin, _elapsedSteps;
    MemoryCard *_lastRevealed;
    bool _canReveal, _isGameStarted;
    QList<MemoryCard*> items;

public:
    explicit MemoryGameBoard(QDeclarativeItem *parent = 0);
    MemoryCard *lastRevealed() const;
    void setLastRevealed(MemoryCard *card);
    bool canReveal() const;
    void saveData(QDataStream &stream) const;
    void loadData(QDataStream &stream);

    unsigned rows() const;
    void setRows(unsigned value);
    unsigned columns() const;
    void setColumns(unsigned value);
    unsigned elapsedSteps() const;
    bool isGameStarted() const;

    static QList<char> generateChars(unsigned n);

signals:
    void rowsChanged();
    void columnsChanged();
    void elapsedStepsChanged();
    void isGameStartedChanged();
    void gameWon();

public slots:
    void cardMatched();
    void startGame();
    void surrenderGame();
    void enableReveal();
    void changeOrientation();

};

#endif // MEMORYGAMEBOARD_H
