import QtQuick 1.1
import com.meego 1.0
import com.meego.extras 1.0
import MemoryGame 1.0

Page {
    id: mainPage
    property MemoryGameBoard board: memoryGameBoard
    tools: ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            id: quitButton
            platformIconId: "toolbar-close";
            onClicked: quitGame()
        }
        ToolButton {
            id: stepsButton
            text: memoryGameBoard.elapsedSteps
            onClicked: elapsedBanner.show()
            width: 50
            height: 50
        }
        ToolIcon {
            id: surrenderButton
            platformIconId: "toolbar-mediacontrol-stop"
            onClicked: surrenderDialog.open()
            visible: memoryGameBoard.isGameStarted
        }
        ToolIcon {
            id: newGameButton
            platformIconId: "toolbar-mediacontrol-play"
            onClicked: {
                settingsSheet.close();
                memoryGameBoard.startGame();
            }
            visible: !memoryGameBoard.isGameStarted
        }
        ToolIcon {
            id: settingsButton
            platformIconId: "toolbar-settings"
            onClicked: {
                if (settingsSheet.visible)
                    settingsSheet.close();
                else
                    settingsSheet.open();
            }
        }
        ToolIcon {
            platformIconId: "toolbar-view-menu";
            anchors.right: parent===undefined ? undefined : parent.right
            onClicked: (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close()
        }
    }

    MemoryGameBoard {
        id: memoryGameBoard
        anchors.fill: parent
        rows: appSettings.rows
        columns: appSettings.columns
        onGameWon: {
            wonDialog.open();
            memoryGameBoard.startGame();
        }
    }

    QueryDialog {
        id: surrenderDialog
        message: "Do you seriously want to abandon this game?"
        acceptButtonText: "Yeah"
        rejectButtonText: "Nope"
        titleText: "Are you sure?"
        onAccepted:
        {
            settingsSheet.close();
            memoryGameBoard.surrenderGame();
        }
    }

    QueryDialog {
        id: wonDialog
        message: "You have successfully solved the given game. Try yourself at another one!"
        titleText: "You rock!"
        acceptButtonText: ""
        rejectButtonText: ""
    }

    InfoBanner {
        id: elapsedBanner
        text: "Elapsed steps: " + memoryGameBoard.elapsedSteps
    }

}
